aboutsummaryrefslogtreecommitdiffhomepage
path: root/internal/pkg/compress.go
diff options
context:
space:
mode:
authorOphestra <cat@gensokyo.uk>2026-07-02 22:59:40 +0900
committerOphestra <cat@gensokyo.uk>2026-07-02 23:21:31 +0900
commitdde69dde61e57fa929596294f6b4e8f798f5598e (patch)
treeda95820f75371a14da57d934cfd5c0ce1f105bef /internal/pkg/compress.go
parent3ba6609444978907fe047007f5218271ba97a153 (diff)
internal/pkg: rename inputs method
Inputs is more correct than dependencies in the current terminology. Signed-off-by: Ophestra <cat@gensokyo.uk>
Diffstat (limited to 'internal/pkg/compress.go')
-rw-r--r--internal/pkg/compress.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/pkg/compress.go b/internal/pkg/compress.go
index 838cd98a..50303419 100644
--- a/internal/pkg/compress.go
+++ b/internal/pkg/compress.go
@@ -66,8 +66,8 @@ func init() {
})
}
-// Dependencies returns a slice containing the backing file.
-func (a *decompressArtifact) Dependencies() []Artifact {
+// Inputs returns a slice containing the backing file.
+func (a *decompressArtifact) Inputs() []Artifact {
return []Artifact{a.f}
}